@@ -82,7 +82,7 @@ usage = '[files to copy to/from]'
 if __name__ == '__main__':
     raise SystemExit('This should be run as kitten clipboard')
 elif __name__ == '__doc__':
-    from kitty.cli import CompletionSpec
+    from kitty.simple_cli_definitions import CompletionSpec
     cd = sys.cli_docs  # type: ignore
     cd['usage'] = usage
     cd['options'] = OPTIONS
